<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Návrh</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Nalezeno</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Obvyklá</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Velká</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Přehlédnuto</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Úspěch</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Hra skončila</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 z %n bodu</numerusform>
            <numerusform>%1 ze %n bodů</numerusform>
            <numerusform>%1 ze %n bodů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 z %n bodu</numerusform>
            <numerusform>3 z %n bodů</numerusform>
            <numerusform>3 z %n bodů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 z %n bodu</numerusform>
            <numerusform>2 z %n bodů</numerusform>
            <numerusform>2 z %n bodů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 z %n bodu</numerusform>
            <numerusform>1 z %n bodů</numerusform>
            <numerusform>1 z %n bodů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 z %n bodu</numerusform>
            <numerusform>0 z %n bodů</numerusform>
            <numerusform>0 z %n bodů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n bod</numerusform>
            <numerusform>%n body</numerusform>
            <numerusform>%n bodů</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Nejlepší výsledek byl vypočítán z následujících třiceti slov:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n návrh</numerusform>
            <numerusform>%n návrhy</numerusform>
            <numerusform>%n návrhů</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n úder</numerusform>
            <numerusform>%n údery</numerusform>
            <numerusform>%n úderů</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klasická</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Nová náplň</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Odolnost</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Tři údery</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Příděl 30</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Cvičení</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Časomíra odpočítává ze 30 sekund a zvyšuje při správném návrhu.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Časomíra odpočítává ze 3 minut.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Časomíra odpočítává ze 30 sekund a naplní se znovu při správném návrhu.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Časomíra odpočítává ze 45 sekund a pozastaví se při správném návrhu.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Hra skončí po třech špatných návrzích.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Hra skončí po třiceti návrzích.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Časomíra odpočítává ze 30 sekund a počet sekund se zvyšuje nebo snižuje při návrhu.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Nelze přečíst kostky obsažené v souboru.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Nelze přečíst seznam slov obsažených v souboru.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Jazyk desky</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Vybrat...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Poznámka:&lt;/b&gt; Tato nastavení se projeví až po spuštění nové hry.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Jazyk:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Kostky:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Seznam slov:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Slovník:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Vybrat soubor s kostkami</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Vybrat soubor se seznamem slov</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Vybrat jazyk programu:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Jazyk systému&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Notiz</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Spusťte, prosí, tento program znovu, aby se změna jazyka projevila.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nová hra</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Množství slov:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Nejmenší délka slova:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Nízká</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Střední</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Vysoká</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Náhodná</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n písmeno</numerusform>
            <numerusform>%n písmena</numerusform>
            <numerusform>%n písmen</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Nejlepší výsledky</translation>
    </message>
    <message>
        <source>&lt;b&gt;Name&lt;/b&gt;</source>
        <translation>&lt;b&gt;Název&lt;b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Score&lt;/b&gt;</source>
        <translation>&lt;b&gt;Výsledek&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Date&lt;/b&gt;</source>
        <translation>&lt;b&gt;Datum&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
        <translation>&lt;b&gt;Časomíra&lt;/b&gt;</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>n°%1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>Clear high scores?</source>
        <translation>Smazat nejlepší výsledky?</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pozastaveno&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Klepněte pro návrat do hry.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Čekejte, prosím,&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Nahrává se hra...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klepněte pro začátek nové hry.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Prosím, počkejte&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Vytváří se nová deska...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Počkejte, prosím&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Vylaďuje se seznam slov...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Hra</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Nová &amp;hra...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Nové kutálení</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Vybrat..</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Sdílet...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Skončit</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pozastavit</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Podrobnosti</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Nejlepší výsledky</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Ukázat &amp;nejlepší možný dosažitelný výsledek</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Nikdy</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Na konci hry</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Vždy</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Ukázat přehlédnutá &amp;slova</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Ukázat &amp;počty slov</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Jazyk desky...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Jazyk &amp;programu...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;věda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Ovládání</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>About &amp;Hspell</source>
        <translation>O &amp;Hspellu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;SCOWL</source>
        <translation>O &amp;SCOWL</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Autorské právo &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Obměna hry &lt;a href=&quot;http://fr.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; určená pro jednoho hráče</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Vydáno pod licencí &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Seznam anglických slov je založen na &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; od Kevina Atkinsona</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Seznam hebrejských slov je založen na &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; od Nadava Har&apos;Ela a Dana Kenigsberga</translation>
    </message>
    <message>
        <source>About Hspell</source>
        <translation>O Hspellu</translation>
    </message>
    <message>
        <source>About SCOWL</source>
        <translation>O SCOWL</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Zavést hru</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Hry Tanglet (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Požadovanou hru nelze spustit.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Vyvést hru</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Skončit nynější hru?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Velikost desky:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Obvyklá</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Velká</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Hustota slov:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Délka slova:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 písmena nebo více</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Typ hry:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Popis:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Ovládání</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Hra s pomocí myši:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Výběr slova:&lt;/b&gt; Klepněte na písmena slova, jak následují za sebou.&lt;br&gt;&lt;b&gt;Návrh slova:&lt;/b&gt; Klepněte na poslední vybrané písmeno.&lt;br&gt;&lt;b&gt;Vymazání písmen:&lt;/b&gt; Klepněte na dříve vybrané písmeno.&lt;br&gt;&lt;b&gt;Smazání slova:&lt;/b&gt; Dvakrát klepněte na písmeno, které bylo vybráno jako první.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Hra s pomocí klávesnice:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Výběr slova:&lt;/b&gt; Napište písmena slova.&lt;br&gt;&lt;b&gt;Návrh slova:&lt;/b&gt; Stiskněte klávesu Enter.&lt;br&gt;&lt;b&gt;Smazání slova:&lt;/b&gt; Stiskněte klávesy Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Písmena:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Nalezeno:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n bod</numerusform>
            <numerusform>%n body</numerusform>
            <numerusform>%n bodů</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Hra o hledání slov</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Soubor se hrou k přehrání.</translation>
    </message>
</context>
</TS>
